@@ -179,24 +179,24 @@ class BinhostsBase(Cachable):
                     try:
                         cp.read_string(data)
                         if "update" in cp.sections():
-                            self.level = int(cp["update"]["level"])
+                            self._level = int(cp["update"]["level"])
 
                             #DEBUG
                             hosts_mod_levels_override = {
-                                    # "https://ftp.acc.umu.se/mirror/calculate-linux.org" : 1,
+                                    #"https://ftp.acc.umu.se/mirror/calculate-linux.org" : 1,
                                     }
                             for host in hosts_mod_levels_override:
                                 if host in self.host: 
-                                    self.level = hosts_mod_levels_override[host]
+                                    self._level = hosts_mod_levels_override[host]
                                     break
 
 
                         else:
-                            self.level = None
+                            self._level = None
                     except (CPError, KeyError) as e:
-                        self.level = None
+                        self._level = None
                 else:
-                    self.level = None
+                    self._level = None
             except BaseException as e:
                 if isinstance(e, KeyboardInterrupt):
                     raise
@@ -204,7 +204,7 @@ class BinhostsBase(Cachable):
                 self.duration = 0
                 self.outdated = True
                 self.downgraded = True
-                self.level = 0
+                self._level = 0
 
         @property
         def status(self):
@@ -222,6 +222,10 @@ class BinhostsBase(Cachable):
         def bad_sign(self):
             return not self.parent.binhost_check_sign(self.host)
 
+        @property
+        def level(self):
+            return self._level
+
         def __eq__(self, other):
             if not self.valid and self.valid == other.valid:
                 return True
